@@ -2,8 +2,8 @@
 #' 
 #' @description Fold change (\eqn{\Delta \Delta C_T} method) analysis of qPCR data can be done using 
 #' ANOVA (analysis of variance) and ANCOVA (analysis of covariance) by the 
-#' \code{qpcrANOVAFC} function, for uni- or multi-factorial experiment data. The bar plot of the fold changes (FC) 
-#' values along with the standard error (se) and confidence interval (ci) is returned by 
+#' \code{qpcrANOVAFC} function, for uni- or multi-factorial experiment data. The bar plot of the fold change (FC) 
+#' values along with the standard error (se) and confidence interval (ci) are returned by 
 #' the \code{qpcrANOVAFC} function. 
 #' 
 #' @details Fold change (\eqn{\Delta \Delta C_T} method) analysis of qPCR data can be done using 
@@ -47,7 +47,7 @@
 #' the first level of the \code{mainFactor.column} is used 
 #' as calibrator. If a vector of main factor levels (in any order) is specified, the first level in the vector is 
 #' used as calibrator. Calibrator is the reference level or sample that all others are compared to. Examples are untreated 
-#' of time 0. The FC value of the reference or calibrator level is 1 because it is not changed compared to itself.
+#' or time 0. The FC value of the reference or calibrator level is 1 because it is not changed compared to itself.
 #' 
 #' @param width a positive number determining bar width. 
 #' @param fill  specify the fill color for the columns in the bar plot. If a vector of two colors is specified, 
@@ -98,7 +98,7 @@
 #'
 #'
 #' qpcrANOVAFC(data_1factor, numberOfrefGenes = 1, mainFactor.column = 1, block = NULL, 
-#' fill = c("#CDC673", "#EEDD82"), fontsizePvalue = 5, y.axis.adjust = 0.1)
+#' fill = c("grey", "skyblue"), fontsizePvalue = 5, y.axis.adjust = 0.1)
 #' 
 #'
 #' qpcrANOVAFC(data_2factor, numberOfrefGenes = 1, mainFactor.column = 2, block = NULL, 
@@ -109,12 +109,12 @@
 #' # replicates so we get mean of technical replicates first:
 #' df <- meanTech(Lee_etal2020qPCR, groups = 1:3)
 #' qpcrANOVAFC(df, numberOfrefGenes = 1, analysisType = "ancova", block = NULL, 
-#' mainFactor.column = 2, fill = c("skyblue", "#BFEFFF"), y.axis.adjust = 0.05)
+#' mainFactor.column = 2, fill = c("grey", "skyblue"), y.axis.adjust = 0.05)
 #' 
 #' 
 #' qpcrANOVAFC(data_2factorBlock,  numberOfrefGenes = 1, mainFactor.column = 1, 
 #' mainFactor.level.order = c("S", "R"), block = "block", 
-#' fill = c("#CDC673", "#EEDD82"), analysisType = "ancova",
+#' fill = c("grey", "skyblue"), analysisType = "ancova",
 #' fontsizePvalue = 7, y.axis.adjust = 0.1, width = 0.35)
 #' 
 #' 
@@ -126,7 +126,7 @@
 #'
 #' addline_format <- function(x,...){gsub('\\s','\n',x)}
 #' qpcrANOVAFC(data_1factor, numberOfrefGenes = 1, mainFactor.column = 1,
-#' block = NULL, fill = c("skyblue","#79CDCD"), y.axis.by = 1, 
+#' block = NULL, fill = c("grey", "skyblue"), y.axis.by = 1, 
 #' letter.position.adjust = 0, y.axis.adjust = 1, ylab = "Fold Change", 
 #' fontsize = 12, x.axis.labels.rename = addline_format(c("Control", 
 #'                                          "Treatment_1 vs Control", 
@@ -142,7 +142,7 @@ analysisType = "anova",
 mainFactor.level.order = NULL, 
 block, 
 width = 0.5, 
-fill = "#BFEFFF", 
+fill = "skyblue", 
 y.axis.adjust = 2, 
 y.axis.by = 1, 
 letter.position.adjust = 0.1, 
@@ -309,7 +309,7 @@ plot = TRUE
  
   
   
-  pp1 <- emmeans(lm, colnames(x)[1], data = x, adjust = p.adj)
+  pp1 <- emmeans(lm, colnames(x)[1], data = x, adjust = p.adj, mode = "satterthwaite")
   pp2 <- as.data.frame(graphics::pairs(pp1), adjust = p.adj)
   pp3 <- pp2[1:length(mainFactor.level.order)-1,]
   ci <- as.data.frame(stats::confint(graphics::pairs(pp1)), adjust = p.adj)[1:length(unique(x[,1]))-1,]
